InsetPlot
=========

.. currentmodule:: stonerplots

.. autoclass:: InsetPlot
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~InsetPlot.locations

   .. rubric:: Attributes Documentation

   .. autoattribute:: locations
